import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:doxdialer_swift_java/doxdialer_swift_java.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  final _phoneNumberController = TextEditingController();

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    try {
      platformVersion = await DoxdialerSwiftJava.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  Future<void> doxdialer(String phoneNumber) async {
    try {
      await DoxdialerSwiftJava.doxdialer(phoneNumber);
    } on PlatformException {
      print('Failed to invoke doxdialer');
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Doxdialer Plugin example app'),
        ),
        body: Column(
          children: <Widget>[
            Center(
              child: Text('Running on: $_platformVersion\n'),
            ),
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: TextField(
                style: TextStyle(
                  fontSize: 17.0,
                  color: Colors.black,
                ),
                decoration: InputDecoration(
                  hintText: 'Enter phone number',
                ),
                keyboardType: TextInputType.number,
                controller: _phoneNumberController,
              ),
            ),
            RaisedButton(
              child: Text(
                'Doximity Dialer',
                style: TextStyle(color: Colors.black),
              ),
              onPressed: () {
                print(_phoneNumberController.text);
                doxdialer(_phoneNumberController.text);
              },
            )
          ],
        ),
      ),
    );
  }
}
